==> e2clab-2.1.1b2.tar.gz: e2clab-2.1.1b2/e2clab/schemas/network_schema.py <==
from jsonschema import Draft7Validator

from e2clab.constants import (
    NET_DELAY,
    NET_DST,
    NET_LOSS,
    NET_NETWORKS,
    NET_RATE,
    NET_SRC,
    NET_SYMMETRIC,
)

SCHEMA: dict = {
    "description": "Experiment Network description",
    "type": "object",
    "properties": {
        NET_NETWORKS: {
            "type": ["array", "null"],
            "items": {"$ref": "#/definitions/network"},
        }
    },
    "required": [NET_NETWORKS],
    "additionalProperties": False,
    "definitions": {
        "network": {
            "title": "Network emulation",
            # "$$target": "#/definitons/network",
            "type": "object",
            "properties": {
                NET_SRC: {
                    "description": "Source layer name",
                    "type": "string",
                },
                NET_DST: {
                    "description": "Destination layer name",
                    "type": "string",
                },
                NET_DELAY: {
                    "description": "The delay to apply",
                    "type": "string",
                    "examples": ["10ms", "1ms"],
                },
                NET_RATE: {
                    "description": "The rate to apply",
                    "type": "string",
                    "examples": ["1gbit", "100mbit"],
                },
                NET_LOSS: {
                    "description": "The percentage of loss",
                    "type": "string",
                    "pattern": r"\d*.?\d*%",
                    "examples": ["1%", "5%"],
                },
                NET_SYMMETRIC: {
                    "description": "True for symmetric rules to be applied",
                    "type": "boolean",
                },
            },
            "required": [NET_SRC, NET_DST],
            "additionalProperties": False,
        }
    },
}

NetworkValidator: Draft7Validator = Draft7Validator(SCHEMA)

==> e2clab-3.3.0.tar.gz: e2clab-3.3.0/e2clab/schemas/network_schema.py <==
from jsonschema import Draft7Validator

from e2clab.constants.network import DELAY, DST, LOSS, NETWORKS, RATE, SRC, SYMMETRIC

SCHEMA: dict = {
    "description": "Experiment Network description",
    "type": "object",
    "properties": {
        NETWORKS: {
            "type": ["array", "null"],
            "items": {"$ref": "#/definitions/network"},
        }
    },
    "required": [NETWORKS],
    "additionalProperties": False,
    "definitions": {
        "network": {
            "title": "Network emulation",
            # "$$target": "#/definitons/network",
            "type": "object",
            "properties": {
                SRC: {
                    "description": "Source layer name",
                    "type": "string",
                },
                DST: {
                    "description": "Destination layer name",
                    "type": "string",
                },
                DELAY: {
                    "description": "The delay to apply",
                    "type": "string",
                    "examples": ["10ms", "1ms"],
                },
                RATE: {
                    "description": "The rate to apply",
                    "type": "string",
                    "examples": ["1gbit", "100mbit"],
                },
                LOSS: {
                    "description": "The percentage of loss",
                    "type": "string",
                    "pattern": r"\d*.?\d*%",
                    "examples": ["1%", "5%"],
                },
                SYMMETRIC: {
                    "description": "True for symmetric rules to be applied",
                    "type": "boolean",
                },
            },
            "required": [SRC, DST],
            "additionalProperties": False,
        }
    },
}

NetworkValidator: Draft7Validator = Draft7Validator(SCHEMA)
